PopupDisplayOptions class

Controls the appearance of popups.

Constructors

PopupDisplayOptions({required PopupBuilder builder, PopupSnap snap = PopupSnap.markerTop, PopupAnimation? animation})
const

Properties

animation → PopupAnimation?
Allows the use of an animation for showing/hiding popups. Defaults to no animation.
final
builder → PopupBuilder
Used to construct the popup.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snap → PopupSnap
Determines the position of the popup relative to the marker or popup.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited