PopupSpec class

Contains the data relevant for constructing a popup.

Constructors

PopupSpec({required Marker marker, int? removeIfZoomLessThan, String? namespace, LatLng? markerPointOverride, Alignment? markerAlignmentOverride})
PopupSpec.wrap(Marker marker)
A convenience constructor for creating a PopupSpec without setting optional fields.

Properties

hashCode → int
The hash code for this object.
no setteroverride
key → Key
Used internally to maintain the popup's state when it is off-screen.
final
marker → Marker
The Marker for which this popup should be shown.
final
markerAlignment → Alignment
no setter
markerAlignmentOverride → Alignment?
Override the marker's anchor. This will only affect popup placement when using a marker snap.
final
markerHeight → double
no setter
markerPoint → LatLng
//////////////////////////// Marker method overrides // ////////////////////////////
no setter
markerPointOverride → LatLng?
Override the marker's point. This will only affect popup placement when using a marker snap.
final
markerRotate → bool
///////////////////////// Marker method proxies // /////////////////////////
no setter
markerWidth → double
no setter
namespace → String?
final
removeIfZoomLessThan → int?
If set this popup will removed when the map zoom rounded up to the nearest int is less than this value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

unwrap(PopupSpec popupSpec) → Marker
A convenience method for extracting the marker from a PopupSpec. Particularly handy for lists e.g. popupSpecs.map(PopupSpec.unwrap).